@@ -126,7 +126,8 @@ OTC_SERVICES = {
         'service_type': 'lts'
     },
     'mrs': {
-        'service_type': 'mrs'
+        'service_type': 'mrs',
+        'append_project_id': True,
     },
     'nat': {
         'service_type': 'nat',
@@ -146,7 +147,8 @@ OTC_SERVICES = {
         'append_project_id': True
     },
     'sdrs': {
-        'service_type': 'sdrs'
+        'service_type': 'sdrs',
+        'append_project_id': True
     },
     'sfsturbo': {
         'service_type': 'sfsturbo',
